package com.muyu.cloud.market.domin;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.cloud.market.domin.req.CompanyListReq;
import com.muyu.cloud.market.domin.req.ProductAddReq;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.math.BigDecimal;
import java.util.Date;

/**
 * @Author：weiran
 * @Package：com.muyu.cloud.background.domin
 * @Project：cloud-background
 * @name：Company
 * @Date：2024/8/26 18:44
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@SuperBuilder
@TableName(value = "company",autoResultMap = true)
public class Company {
    /**
     * 企业ID
     */
    @TableId(value = "company_id",type = IdType.AUTO)
    private Integer companyId;
    /**
     *企业名称
     */
    private String companyName;
    /**
     *企业头像
     */
    private String companyPhoto;
    /**
     * 企业法人
     */
    private String companyLeader;
    /**
     *注册人姓名
     */
    private String registrantName;
    /**
     *注册人联系方式
     */
    private String registrantPhone;
    /**
     *注册人职位
     */
    private String registrantPosition;
    /**
     *注册日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Schema(description = "注册日期",defaultValue = "2024-8-9",type = "String",format = "date")
    private Date registrantDate;
    /**
     *社会统一信用代码
     */
    private String usci;
    /**
     *企业营业执照
     */
    private String businessLicense;
    /**
     *企业地址
     */
    private String companyAddress;
    /**
     *审核状态
     */
    private Integer reviewStatus;
    /**
     * 公司注册账户余额
     */
    private BigDecimal companyMoney;


    public static Company companyList(CompanyListReq companyListReq){
        return Company.builder()
                .companyId(null)
                .companyName(companyListReq.getCompanyName())
                .companyPhoto(companyListReq.getCompanyPhoto())
                .companyLeader(companyListReq.getCompanyLeader())
                .registrantName(companyListReq.getRegistrantName())
                .registrantPhone(companyListReq.getRegistrantPhone())
                .registrantPosition(companyListReq.getRegistrantPhone())
                .registrantDate(companyListReq.getRegistrantDate())
                .usci(companyListReq.getUsci())
                .businessLicense(companyListReq.getBusinessLicense())
                .companyAddress(companyListReq.getCompanyAddress())
                .reviewStatus(companyListReq.getReviewStatus())
                .companyMoney(companyListReq.getCompanyMoney())
                .build();
    }
}
