package com.muyu.cloud.market.domin;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.cloud.market.domin.req.ProductAddReq;
import com.muyu.cloud.market.domin.req.ProductUpdReq;
import com.muyu.common.core.web.domain.BaseEntity;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.experimental.SuperBuilder;

import java.math.BigDecimal;
import java.util.Date;
import java.util.function.Supplier;

/**
 * @Author：weiran
 * @Package：com.muyu.cloud.market.domin
 * @Project：cloud-market
 * @name：Product
 * @Date：2024/8/20 15:04
 */
@EqualsAndHashCode(callSuper = true)
@Data
@AllArgsConstructor
@NoArgsConstructor
@SuperBuilder
@TableName(value = "product",autoResultMap = true)
public class Product extends BaseEntity {

    /**
     * 主键
     */
    @TableId(value = "product_id",type = IdType.AUTO)
    private Integer productId;
    /**
     * 产品名称
     */
    private String productName;
    /**
     *产品价格
     */
    private BigDecimal productPrice;
    /**
     *产品介绍
     */
    private String productContent;
    /**
     *产品上架状态（是否上架 0未上架 1已上架）
     */
    private Integer productState;
    /**
     *产品规格（按次购买/按日期购买）购买多少次
     */
    private String productSpecification;
    /**
     *产品销量
     */
    private Integer productSales;
    /**
     * 产品类型
     */
    private String productType;
    /**
     *产品上架日期
     */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Schema(description = "产品上架日期",defaultValue = "2024-8-9 10:47:57",type = "Date")
    private Date productShelvesdate;
    /**
     * 重要路径
     */
    private String apiRouter;
    /**
     *接口地址
     */
    private String apiAddress;
    /**
     * 返回格式
     */
    private String returnFormat;
    /**
     *请求方式
     */
    private String requestMethod;

    /**
     * 允许试用次数
     */
    private Integer userCount;
    /**
     * 是否被购买
     */
    private String remark;




    public static Product addProductList(ProductAddReq productAddReq){
        return Product.builder()
                .productId(null)
                .productName(productAddReq.getProductName())
                .productPrice(productAddReq.getProductPrice())
                .productContent(productAddReq.getProductContent())
                .productState(productAddReq.getProductState())
                .productSpecification(productAddReq.getProductSpecification())
                .productSales(productAddReq.getProductSales())
                .productType(productAddReq.getProductType())
                .productShelvesdate(productAddReq.getProductShelvesdate())
                .apiAddress(productAddReq.getApiAddress())
                .returnFormat(productAddReq.getReturnFormat())
                .requestMethod(productAddReq.getRequestMethod())
                .apiRouter(productAddReq.getApiRouter())
                .build();
    }


    public static Product updProductList(ProductUpdReq productUpdReq, Supplier<Integer> idSupplier){
        return Product.builder()
                .productId(productUpdReq.getProductId())
                .productName(productUpdReq.getProductName())
                .productPrice(productUpdReq.getProductPrice())
                .productContent(productUpdReq.getProductContent())
                .productState(productUpdReq.getProductState())
                .productSpecification(productUpdReq.getProductSpecification())
                .productSales(productUpdReq.getProductSales())
                .productType(productUpdReq.getProductType())
                .productShelvesdate(productUpdReq.getProductShelvesdate())
                .apiAddress(productUpdReq.getApiAddress())
                .returnFormat(productUpdReq.getReturnFormat())
                .requestMethod(productUpdReq.getRequestMethod())
                .apiRouter(productUpdReq.getApiRouter())
                .build();
    }



}
