package com.muyu.cloud.market.domin.req;

import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotEmpty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.Date;

@Tag(name = "订单信息列表请求对象",description = "根据入参进行服务的添加")
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
public class OrdersAddReq {

    /**
     * 订单编号
     */
    @Schema(
            title = "订单服务编号",
            description = "‘订单编码’和订单id主键不同，由产品类别批次系统构建"
    )
    private String ordersNum;



    /**
     * 订单产品（产品外键）
     */
    @Schema(title = "订单产品（产品外键）",
            type = "Integer")
    private Integer ordersProduct;

    /**
     * 订单所属人（user外键）
     */
    @Schema(title = "订单所属人（用户外键）",
            type = "Integer")
    private Integer ordersUser;

    /**
     * 订单金额
     */
    @Schema(
            title = "订单金额",
            description = "订单金额方向需使用特殊操作处理",
            type = "BigDecimal"
    )
    private BigDecimal ordersPrice;

    /**
     * 订单规格
     */
    @Schema(
            description = "订单规格",
            type = "String"
    )
    private String  ordersSpecification;

    /**
     * 订单状态（已付款，未付款，待支付）
     */
    @Schema(
            title = "订单状态",
            description = "订单状态:0-待支付 1-已付款 2-已取消"
    )
    private Integer ordersState;

    /**
     * 订单日期
     */
    @Schema(
            description = "订单日期",
            type = "Date"
    )
    private Date ordersLaunchdate;




}
