package com.muyu.cloud.market.domin.resp;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.cloud.market.domin.Orders;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.format.annotation.DateTimeFormat;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.function.Supplier;

@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@Tag(name = "订单信息响应对象",description = "负责订单信息查询的响应结果")
public class OrdersResp {


    /**
     * 订单表ID
     */
    @Schema(description = "订单表ID",
            defaultValue = "1",
            type = "Long")
    private Long ordersId;

    /**
     * 订单编号
     */
    @Schema(description = "订单编号",
            type = "String")
    private String ordersNum;

    /**
     * 订单产品（产品外键）
     */
    @Schema(description = "订单产品（产品外键）",
            type = "Integer")
    private Integer ordersProduct;

    /**
     * 订单所属人（user外键）
     */
    @Schema(description = "订单所属人（user外键）",
            type = "Integer")
    private Integer ordersUser;

    /**
     * 订单金额
     */
    @Schema(description = "订单金额",
            type = "BigDecimal")
    private BigDecimal ordersPrice;

    /**
     * 订单规格
     */
    @Schema(description = "订单规格",
            type = "String")
    private String  ordersSpecification;

    /**
     * 订单状态（已付款，未付款，待支付）
     */
    @Schema(description = "订单状态（已付款，未付款，待支付）",
            type = "Integer")
    private Integer ordersState;

    /**
     * 订单日期
     */
    @Schema(description = "订单日期",
            type = "Date")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date ordersLaunchdate;

    /**
     * 逻辑删除字段
     */
    @Schema(description = "逻辑删除字段",
            type = "Interger")
    private Integer exist;

    public static OrdersResp ordersresp(Orders orders, Supplier<List<OrdersResp>> function){

        return OrdersResp.builder()
                .ordersId(orders.getOrdersId())
                .ordersNum(orders.getOrdersNum())
                .ordersProduct(orders.getOrdersProduct())
                .ordersUser(orders.getOrdersUser())
                .ordersPrice(orders.getOrdersPrice())
                .ordersSpecification(orders.getOrdersSpecification())
                .ordersState(orders.getOrdersState())
                .ordersLaunchdate(orders.getOrdersLaunchdate())
                .build();
    }





}
