package com.muyu.cloud.market.domin.resp;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.muyu.cloud.market.domin.Product;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.Date;

/**
 * @Author：weiran
 * @Package：com.muyu.cloud.market.domin.resp
 * @Project：cloud-market
 * @name：ProductListResp
 * @Date：2024/8/21 15:06
 */

@Data
@Builder
@AllArgsConstructor
@Tag(name="接口产品信息响应对象",description = "接口产品查询的响应结果")
public class ProductListResp {
    /**
     * 主键
     */
    private Integer productId;
    /**
     * 产品名称
     */
    private String productName;
    /**
     *产品价格
     */
    private BigDecimal productPrice;
    /**
     *产品介绍
     */
    private String productContent;
    /**
     *产品上架状态（是否上架 0未上架 1已上架）
     */
    private Integer productState;
    /**
     * 产品销量
     */
    private Integer productSales;
    /**
     *接口地址
     */
    private String apiAddress;
    /**
     * 返回格式
     */
    private String returnFormat;
    /**
     *请求方式
     */
    private String requestMethod;
    /**
     * 重要路径
     */
    private String apiRouter;
    /**
     * 允许试用次数
     */
    private Integer userCount;
    /**
     * 是否被购买
     */
    private String remark;

    @Schema(description = "创建人",defaultValue = "muyu",type = "String")
    private String createBy;
    @JsonFormat(
            pattern = "yyyy-MM-dd "
    )
    @Schema(description = "创建时间",defaultValue = "2024-07-31 ",type = "Date")
    private Date createTime;




    /**
     * 数据库对象构建为返回结果对象
     * @param product
     * @return
     */
    public static ProductListResp productListRespbuild(Product product){
        return ProductListResp.builder()
                .productId(product.getProductId())
                .productName(product.getProductName())
                .productPrice(product.getProductPrice())
                .productContent(product.getProductContent())
                .productState(product.getProductState())
                .productSales(product.getProductSales())
                .apiAddress(product.getApiAddress())
                .returnFormat(product.getReturnFormat())
                .requestMethod(product.getRequestMethod())
                .apiRouter(product.getApiRouter())
                .remark(product.getRemark())
                .userCount(product.getUserCount())
                .createBy(product.getCreateBy())
                .createTime(product.getCreateTime())
                .build();
    }
}
