package com.muyu.cloud.market.controller;
import com.muyu.cloud.market.domin.Product;
import com.muyu.cloud.market.domin.User;
import com.muyu.cloud.market.domin.req.CompanyListReq;
import com.muyu.cloud.market.service.CompanyService;
import com.muyu.cloud.market.util.OssUtil;
import com.muyu.common.core.domain.Result;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

/**
 * @Author：weiran
 * @Package：com.muyu.cloud.market.controller
 * @Project：cloud-market
 * @name：CompanyController
 * @Date：2024/8/27 14:16
 */

@Log4j2
@RestController
@RequestMapping("/company")
@Tag(name = "企业管理控制层",description = "进行企业管理、查看等相关操作")
public class CompanyController {
    @Autowired
    private CompanyService companyService;


    /**
     *
     * 图片上传
     * @param file
     * @return
     */
    @PostMapping(path = "/upload")
    @Operation(summary = "图片上传",description = "图片上传")
    public Result upload(MultipartFile file){
        String s=OssUtil.uploadMultipartFile(file);
        return Result.success(s);
    }


    /**
     * 企业绑定
     * @param companyListReq
     * @return
     */
    @PostMapping(path = "/companyauthentication")
    @Operation(summary = "企业绑定",description = "企业绑定")
    public Result companyauthentication(@Validated @RequestBody CompanyListReq companyListReq, HttpServletRequest request){
        companyService.companyauthentication(companyListReq,request);
        return Result.success(null,"绑定成功");
    }


    /**
     * 判断是否进行了企业绑定
     * @return
     */
    @PostMapping("/ifcompanyauthentication")
    @Operation(summary = "是否企业绑定了",description = "是否企业绑定了")
    public Result ifcompanyauthentication(){
        User user = companyService.ifcompanyauthentication();
        if (null==user.getIsCompanyid() || user.getIsCompanyid().intValue()==0){
            return Result.error("请先进行企业绑定");
        }
        return Result.success(null,"绑定成功");
    }


    /**
     * 绑定的企业信息
     * @return
     */
    @PostMapping("/selectcompany")
    @Operation(summary = "绑定的企业信息",description = "查看绑定的企业信息")
    public Result selectcompany(HttpServletRequest request){
        return Result.success(companyService.selectcompany(request));
    }











}
