package com.muyu.cloud.market.controller;

import com.muyu.cloud.market.domin.Customer;
import com.muyu.cloud.market.domin.resp.CustomerListResp;
import com.muyu.cloud.market.service.FindCustomerMeaasgeService;
import com.muyu.common.core.domain.Result;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @Author：weiran
 * @Package：com.muyu.cloud.market.controller
 * @Project：cloud-market
 * @name：FindUserMeaasgeController
 * @Date：2024/8/20 9:42
 */
@Log4j2
@RestController
@RequestMapping("customer")
@Tag(name = "客户控制层",description = "进行客户信息管理、查看等相关操作")
public class FindCustomerMeaasgeController {

    /**
     * 客户信息业务层
     */
    @Autowired
    private FindCustomerMeaasgeService findCustomerMeaasgeService;


    /**
     * 根据身份证号查询客户信息
     * @param idCard
     * @return
     */
    @PostMapping(path = "/findListByuserCard/{idCard}")
    @Operation(summary = "身份证号查询客户信息",description = "根据身份证号查询客户信息")
    public Result<Customer> findListByuserCard(@Validated @PathVariable String idCard){
        return Result.success(findCustomerMeaasgeService.findListByuserCard(idCard));
    }

    /**
     * 根据手机号查询客户信息
     * @param tel
     * @return
     */
    @PostMapping(path = "/findListByuserPhone/{tel}")
    @Operation(summary = "手机号查询客户信息",description = "根据手机号查询客户信息")
    public Result<Customer> findListByuserPhone(@Validated @PathVariable String tel){
        return Result.success(findCustomerMeaasgeService.findListByuserPhone(tel));
    }









}
