package com.muyu.cloud.market.controller;

import com.muyu.cloud.market.domin.req.CustomerAddReq;
import com.muyu.cloud.market.domin.req.CustomerUpdReq;
import com.muyu.cloud.market.service.InsideCustomerMessageService;
import com.muyu.common.core.domain.Result;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @Author：weiran
 * @Package：com.muyu.cloud.market.controller
 * @Project：cloud-market
 * @name：InsideUseInterfaceController
 * @Date：2024/8/20 20:42
 */
@Log4j2
@RestController
@RequestMapping("InsideCostomerMessage")
@Tag(name = "内部使用控制层",description = "进行公司内部用户信息使用管理、增删改等相关操作")
public class InsideCustomerMessageController {

    /**
     * 内部使用业务层
     */
    @Autowired
    private InsideCustomerMessageService insideCustomerMessageService;

    /**
     * 添加客户信息
     * @return
     */
    @PostMapping
    @Operation(summary = "新增客户信息",description = "客户信息的添加操作")
    public Result addCustomerMessage(@Validated @RequestBody CustomerAddReq customerAddReq){
        insideCustomerMessageService.add(customerAddReq);
        return Result.success(null,"操作成功");
    }

    /**
     * 修改客户信息
     * @param id
     * @param customerUpdReq
     * @return
     */
    @PutMapping("/{id}")
    @Operation(summary = "客户信息修改", description = "通过ID修改客户信息")
    public Result<String> update(
            @Schema(title = "客户ID", type = "Integer", defaultValue = "1", description = "修改客户信息需要依据的唯一条件")
            @PathVariable("id") Integer id,
            @RequestBody @Validated CustomerUpdReq customerUpdReq) {
        insideCustomerMessageService.updateBy(customerUpdReq);
        return Result.success(null, "操作成功");
    }





}
