package com.muyu.cloud.market.controller;

import com.alibaba.nacos.api.naming.pojo.healthcheck.impl.Http;
import com.dtflys.forest.springboot.annotation.ForestScannerRegister;
import com.github.pagehelper.PageInfo;
import com.muyu.cloud.market.domin.Orders;
import com.muyu.cloud.market.domin.req.OrdersAddReq;
import com.muyu.cloud.market.domin.req.OrdersListReq;
import com.muyu.cloud.market.domin.req.OrdersUpdReq;
import com.muyu.cloud.market.service.OrderShowService;
import com.muyu.cloud.market.util.poi.ExcelUtil;
import com.muyu.common.core.domain.Result;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.log4j.Log4j2;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@Log4j2
@RestController
@RequestMapping("/orders")
@Tag(name = "订单控制层", description = "进行订单管理查询操作")
public class OrdersController {
    public OrdersController() {
        log.info("forest{}扫描路径", ForestScannerRegister.getBasePackages());

    }

    @Resource
    private OrderShowService orderShowService;

    /**
     * 展示订单
     * @param
     * @return
     */
    @PostMapping("/list")
    @Operation(summary = "查看订单", description = "根据订单名称 编号 状态 查询")
    public Result<PageInfo<Orders>> selectList(@Validated @RequestBody OrdersListReq req){
        PageInfo<Orders> info = orderShowService.selectList(req);
        log.info("查看订单列表,根据订单名称 编号 状态 查询",req,info);
        return Result.success(info);
    }


    /**
     * 新增订单
     * @param ordersAddReq
     * @return
     */
    @PostMapping("/addOrdeds")
    @Operation(summary = "添加订单", description = "根据ordersAddReq对象添加订单")
    Result addOrdeds(@Validated @RequestBody OrdersAddReq ordersAddReq){
        return orderShowService.addOrdeds(ordersAddReq);
    }

    /**
     * 修改订单
     * @param ordersUpdReq
     * @return
     */
    @PostMapping("/updateOrders")
    @Operation(summary = "修改订单", description = "根据ordersid查找订单进行修改")
    Result updateOrders(@Validated @RequestBody OrdersUpdReq ordersUpdReq){
        Result result = orderShowService.updateOrders(ordersUpdReq);
        log.info(ordersUpdReq);
        return  result;
    }

    /**
     * 逻辑删除->根据orderid修改exist字段 1->0
     * 订单回收站
     * @param ordersId
     * @return
     */
    @GetMapping("/updateByeExist/{ordersId}")
    @Operation(summary = "逻辑删除订单", description = "根据orderid修改exist字段 1->0/(类似回收站)")
    Result updateByeExist (@Validated @PathVariable("ordersId") Integer ordersId){
        return orderShowService.updateByeExist(ordersId);
    }

    /**
     * 逻辑复原->根据orderid修改exist字段 0->1
     * 订单回收站
     * @param ordersId
     * @return
     */
    @GetMapping("/updateByExist/{ordersId}")
    @Operation(summary = "逻辑复原订单", description = "根据orderid修改exist字段 0->1")
    Result updateByExist(@Validated @PathVariable("ordersId") Integer ordersId){
        return orderShowService.updateByExist(ordersId);
    }

    /**
     * 彻底删除(根据orderid删除数据库字段)
     * @return
     */
    @GetMapping("/delByOrderId/{ordersId}")
    @Operation(summary = "彻底删除订单", description = "根据根据orderid删除数据库字段")
    Result delByOrderId(@Validated @PathVariable("ordersId") Integer ordersId){
        return orderShowService.delByOrderId(ordersId);
    }

    /**
     * 回显
     * 根据id查内容
     * @param ordersId
     * @return
     */
    @GetMapping("/findAllById/{ordersId}")
    @Operation(summary = "回显", description = "根据ordersId进行查询信息")
    Orders findAllById (@Validated @PathVariable("ordersId") Integer ordersId){
        return orderShowService.findAllById(ordersId);
    }

    //导出
    @GetMapping("/getOutAll")
    @Operation(summary = "导出")
    public  void gatOutAll(HttpServletResponse response){
        //创建工具类对象
        ExcelUtil<Orders> excelUtil =new ExcelUtil<>(Orders.class);
        //去数据库查询要导出来的数据
        List<Orders> outAll = orderShowService.getOutAll();

        excelUtil.exportExcel(response,outAll ,"订单信息表");
    }

    //选中导出
    @GetMapping("/getseleOut")
    @Operation(summary = "选中导出")
    public void selectOut (HttpServletResponse response,Integer[] ids){
        //创建
        ExcelUtil<Orders> excelUtil = new ExcelUtil<>(Orders.class);
        //去数据库查询要导出来的数据
        List<Orders> list = orderShowService.getseleOut(ids);

        excelUtil.exportExcel(response,list,"订单信息选中导出");
    }

    /**
     * 订单修改支付状态1已付款后,更改该商品的销量
     * （0待支付,1已付款,2未付款,3.售后(申请退款) 4.已退款）
     */
    //订单修改支付状
    @GetMapping("/updateByordersState1")
    @Operation(summary = "订单修改支付状态=1,更改该商品的销量", description = "根据orderid修改数据库字段支付状态为1,根据productId修改数据库销量")
    Result updateByordersState1ANDproductSales(@RequestParam("ordersId")Integer ordersId,@RequestParam("productId")Integer productId){
        return orderShowService.updateByordersState1ANDproductSales(ordersId, productId);
    }

    @PostMapping("/updateByordersState2/{ordersId}")
    @Operation(summary = "订单修改支付状态=2", description = "根据orderid修改数据库字段支付状态为2")
    Result updateByordersState2(@Validated @PathVariable("ordersId") Integer ordersId) {

            return orderShowService.updateByordersState2(ordersId);

    }


    //3.售后(申请退款)
    @PostMapping("/updateByordersState3/{ordersId}")
    @Operation(summary = "订单修改支付状态=3", description = "根据orderid修改数据库字段支付状态为3")
    Result updateByordersState3( @PathVariable("ordersId")Integer ordersId){
        return orderShowService.updateByordersState3(ordersId);
    }
    // 4.已退款
    @PostMapping("/updateByordersState4/{ordersId}")
    @Operation(summary = "订单修改支付状态=4", description = "根据orderid修改数据库字段支付状态为4")
    Result updateByordersState4(@Validated @PathVariable("ordersId")Integer ordersId){
        return orderShowService.updateByordersState4(ordersId);
    }



}
