package com.muyu.cloud.market.controller;

import com.muyu.cloud.market.domin.req.LinkEmailReq;
import com.muyu.cloud.market.service.UserService;
import com.muyu.cloud.market.util.OssUtil;
import com.muyu.common.core.domain.Result;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * @Author：weiran
 * @Package：com.muyu.cloud.market.controller
 * @Project：cloud-market
 * @name：UserController
 * @Date：2024/8/27 19:17
 */
@Log4j2
@RestController
@RequestMapping("/user")
@Tag(name = "登录人信息",description = "进行登录人信息查看等相关操作")
public class UserController {
    @Autowired
    private UserService userService;


    /**
     * 发送邮箱验证
     * @param email
     * @return
     */
    @PostMapping("/sendcode/{email}")
    @Operation(summary = "发送邮箱验证",description = "绑定邮箱时，通过验证码来进行验证")
    public Result sendcode(@PathVariable String email){
        return Result.success(userService.sendcode(email));
    }



    /**
     * 邮箱绑定
     * @param linkEmailReq
     * @return
     */
    @PostMapping(path = "/linkemail")
    @Operation(summary = "绑定邮箱",description = "进行邮箱的绑定")
    public Result linkemail(@RequestBody LinkEmailReq linkEmailReq, HttpServletRequest request){
        userService.linkemail(linkEmailReq,request);
        return Result.success(null, "操作成功");
    }

    /**
     *
     * 图片上传
     * @param file
     * @return
     */
    @PostMapping(path = "/upload")
    @Operation(summary = "图片上传",description = "图片上传")
    public Result upload(MultipartFile file){
        String s= OssUtil.uploadMultipartFile(file);
        return Result.success(s);
    }
}
