package com.muyu.cloud.market.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.cloud.market.domin.Company;
import com.muyu.cloud.market.domin.User;
import com.muyu.cloud.market.domin.req.CompanyListReq;
import com.muyu.cloud.market.domin.resp.UserCompanyResp;
import com.muyu.cloud.market.mapper.CompanyMapper;
import com.muyu.cloud.market.service.CompanyService;
import com.muyu.cloud.market.service.UserService;
import com.muyu.common.security.service.TokenService;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.common.system.domain.LoginUser;
import jakarta.servlet.http.HttpServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.ZoneId;
import java.util.Date;

/**
 * @Author：weiran
 * @Package：com.muyu.cloud.market.service.impl
 * @Project：cloud-market
 * @name：CompanyServiceImpl
 * @Date：2024/8/27 14:17
 */
@Service
public class CompanyServiceImpl extends ServiceImpl<CompanyMapper, Company> implements CompanyService {
    @Autowired
    private CompanyMapper companyMapper;
    @Autowired
    private TokenService tokenService;
    @Autowired
    private UserService userService;



    /**
     * 企业绑定
     * @param companyListReq
     * @return
     */
    @Override
    public void companyauthentication(CompanyListReq companyListReq, HttpServletRequest request) {
        //判断是不是已经绑定
        //获取当前登录人信息
        String token = SecurityUtils.getToken();// 获取当前Token
        LoginUser loginUser = tokenService.getLoginUser(token); // 获取当前登录用户
        if (loginUser == null) {
            throw new RuntimeException("用户未登录或Token无效");
        }
        Long userid = loginUser.getUserid();
        User user = userService.getById(userid);
        if (user.getIsCompanyid()!=null && user.getIsCompanyid()!=0){
            throw new RuntimeException("已绑定，若要重新绑定，请先解除绑定");
        }

        // 使用java.time.LocalDate获取当前日期，并将其转换为java.util.Date
        LocalDate today = LocalDate.now();
        java.util.Date registrantDate = Date.from(today.atStartOfDay(ZoneId.systemDefault()).toInstant());
        companyListReq.setRegistrantDate(registrantDate);
        companyListReq.setReviewStatus(0);
        companyListReq.setCompanyMoney(BigDecimal.valueOf(0.0));

        Company company = Company.companyList(companyListReq);
        this.save(company);
        Integer companyId = company.getCompanyId();

        userService.updcompanyId(userid,companyId);



    }

    /**
     * 判断是否进行了企业认证
     * @return
     */
    @Override
    public User ifcompanyauthentication() {
        //获取当前登录人信息
        String token = SecurityUtils.getToken();// 获取当前Token
        LoginUser loginUser = tokenService.getLoginUser(token); // 获取当前登录用户
        if (loginUser == null) {
            throw new RuntimeException("用户未登录或Token无效");
        }
        Long userid = loginUser.getUserid();
        User user = userService.getById(userid);
        return user;
    }

    /**
     * 绑定的企业信息
     * @return
     */
    @Override
    public UserCompanyResp selectcompany(HttpServletRequest request) {
        //获取当前登录人信息
        String token = SecurityUtils.getToken();// 获取当前Token
        LoginUser loginUser = tokenService.getLoginUser(token); // 获取当前登录用户
        Long userId = loginUser.getUserid();
        UserCompanyResp companyResp = companyMapper.selectcompany(userId);
        return companyResp;
    }

}
