package com.muyu.cloud.market.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.cloud.market.domin.Customer;
import com.muyu.cloud.market.domin.req.CustomerAddReq;
import com.muyu.cloud.market.domin.req.CustomerUpdReq;
import com.muyu.cloud.market.mapper.InsideCustomerMessageMapper;
import com.muyu.cloud.market.service.InsideCustomerMessageService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * @Author：weiran
 * @Package：com.muyu.cloud.market.service.impl
 * @Project：cloud-market
 * @name：InsideUseInterfaceServiceImpl
 * @Date：2024/8/20 20:45
 */
@Service
public class InsideCustomerMessageServiceImpl extends ServiceImpl<InsideCustomerMessageMapper, Customer> implements InsideCustomerMessageService {

    /**
     * 内部使用持久层
     */
    @Autowired
    private InsideCustomerMessageMapper insideCustomerMessageMapper;

    /**
     * 添加客户信息
     *
     */
    @Override
    public void add(CustomerAddReq customerAddReq) {
        Customer customer = new Customer();
        //从身份证中截取出出生日期
        if (customerAddReq.getIdCard().length()!=18){
           throw new RuntimeException();
        }
        String birthday = customerAddReq.getIdCard().substring(6, 14);
        String birthday1=birthday.substring(0, 4) + '-' + birthday.substring(4, 6) + '-' + birthday.substring(6);
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
        //如果转化过程中出现异常，需要捕捉ParseException并进行处理
        try {
            Date birthday2 = simpleDateFormat.parse(birthday1);
            customer.setBirthday(birthday2);
        }catch (ParseException e){
            e.printStackTrace();
        }
        customer.setName(customerAddReq.getName());
        customer.setGender(customerAddReq.getGender());
        customer.setIdCard(customerAddReq.getIdCard());
        customer.setTel(customer.getTel());
        customer.setAddress(customerAddReq.getAddress());
        customer.setCredit(customer.getCredit());
        customer.setEmail(customer.getEmail());
        insideCustomerMessageMapper.insert(customer);
    }

    /**
     * 修改客户信息
     * @param customerUpdReq
     */
    @Override
    public void updateBy(CustomerUpdReq customerUpdReq) {
        Customer customer = new Customer();
        //从身份证中截取出出生日期
        if (customerUpdReq.getIdCard().length()!=18){
            throw new RuntimeException();
        }
        String birthday = customerUpdReq.getIdCard().substring(6, 14);
        String birthday1=birthday.substring(0, 4) + '-' + birthday.substring(4, 6) + '-' + birthday.substring(6);
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd");
        //如果转化过程中出现异常，需要捕捉ParseException并进行处理
        try {
            Date birthday2 = simpleDateFormat.parse(birthday1);
            customer.setBirthday(birthday2);
        }catch (ParseException e){
            e.printStackTrace();
        }
        customer.setId(customerUpdReq.getId());
        customer.setName(customerUpdReq.getName());
        customer.setGender(customerUpdReq.getGender());
        customer.setIdCard(customerUpdReq.getIdCard());
        customer.setTel(customerUpdReq.getTel());
        customer.setAddress(customerUpdReq.getAddress());
        customer.setCredit(customerUpdReq.getCredit());
        customer.setEmail(customerUpdReq.getEmail());
        insideCustomerMessageMapper.updateById(customer);

    }
}
