package com.muyu.cloud.market.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.muyu.cloud.market.domin.Orders;
import com.muyu.cloud.market.domin.req.OrdersAddReq;
import com.muyu.cloud.market.domin.req.OrdersListReq;
import com.muyu.cloud.market.domin.req.OrdersUpdReq;
import com.muyu.cloud.market.mapper.OrderShowMapper;
import com.muyu.cloud.market.service.OrderShowService;
import com.muyu.common.core.domain.Result;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

@Service
@Log4j2
public class OrderShowServiceImpl implements OrderShowService {
    @Resource
    private OrderShowMapper orderShowMapper;
    @Autowired
    private HttpServletResponse response;




    /**
     * 查询订单列表
     * (精确查ordersNum 精确查ordersState 日期范围 startdate enddate)
     *
     * @param req
     * @return
     */
    @Override
    public PageInfo<Orders> selectList(OrdersListReq req) {
        PageHelper.startPage(req.getPageNum(),req.getPageSize());
        List<Orders> ordersList = orderShowMapper.selectList(req);
        PageInfo<Orders> info = new PageInfo<>(ordersList);
        return info;
//        return ordersList;
    }


    /**
     * 新增订单
     * @param ordersAddReq
     * @return
     */
    @Override
    public Result addOrdeds(OrdersAddReq ordersAddReq) {
        Integer addorders = orderShowMapper.addOrdeds(ordersAddReq);
        if(addorders > 0){
        return Result.success(ordersAddReq,"添加订单成功");
        }
        return Result.error(402,"添加订单失败");
    }

    /**
     * 修改订单
     * @param ordersUpdReq
     * @return
     */
    @Override
    public Result updateOrders(OrdersUpdReq ordersUpdReq) {
        Integer updateorders = orderShowMapper.updateOrders(ordersUpdReq);
        if(updateorders > 0){
            return Result.success(ordersUpdReq,"修改订单成功");
        }
        return Result.error(402,"修改订单失败");
    }

    /**
     * 逻辑删除->根据orderid修改exist字段 1->0
     * 订单回收站
     * @param ordersId
     * @return
     */
    @Override
    public Result updateByeExist(Integer ordersId) {
        Integer updatebyexist = orderShowMapper.updateByeExist(ordersId);
        if(updatebyexist > 0){
            return Result.success(ordersId,"删除订单成功(逻辑)");
        }
        return Result.error(402,"删除订单失败(逻辑)");
    }

    /**
     * 逻辑复原->根据orderid修改exist字段 0->1
     * 订单回收站
     * @param ordersId
     * @return
     */
    @Override
    public Result updateByExist(Integer ordersId) {
        Integer updatebyexist = orderShowMapper.updateByExist(ordersId);
        if(updatebyexist > 0){
            return Result.success(ordersId,"复原订单成功(逻辑)");
        }
        return Result.error(402,"复原订单失败(逻辑)");
    }

    /**
     * 彻底删除(根据orderid删除数据库字段)
     * @return
     */
    @Override
    public Result delByOrderId(Integer ordersId) {
        Integer delbyorderId = orderShowMapper.delByOrderId(ordersId);
        if(delbyorderId > 0){
            return Result.success(ordersId,"删除订单成功");
        }
        return Result.error(402,"删除订单失败");

    }

    /**
     * 回显
     * 根据id查内容
     * @param ordersId
     * @return
     */
    @Override
    public Orders findAllById(Integer ordersId) {
         return orderShowMapper.findAllById(ordersId);
    }


    @Override
    public Orders selectByOrderNo(String ordersNum) {
        return null;
    }


    @Override
    public List<Orders> getOutAll() {
        return orderShowMapper.getOutAll();
    }

    @Override
    public List<Orders> getseleOut(Integer[] ids) {
        return orderShowMapper.getSeleOut(ids);
    }

    public Result updateByordersState1ANDproductSales(Integer ordersId, Integer productId) {

        Integer updateByordersState1 = orderShowMapper.updateByordersState1(ordersId);

        if(updateByordersState1 > 0){
            Integer updateByproductSales = orderShowMapper.updateByproductSales(productId);
            if(updateByproductSales > 0){
                log.info("订单信息+产品信息",ordersId,productId);
                Result.success(200,"修改成功");
            }
        }
        return Result.error(402,"修改失败");

    }


    @Override
    public Result updateByordersState2(Integer ordersId) {
        Integer updateByordersState2 = orderShowMapper.updateByordersState2(ordersId);
        if(updateByordersState2 > 0){
            Result.success(ordersId,"修改成功");
        }
        return Result.error(402,"修改失败");
    }

    @Override
    public Result updateByordersState3(Integer ordersId) {
        Integer updateByordersState3 = orderShowMapper.updateByordersState3(ordersId);
        if(updateByordersState3 > 0){
            return Result.success(ordersId,"修改成功");
        }
        return Result.error(402,"修改失败");
    }

    @Override
    public Result updateByordersState4(Integer ordersId) {
        Integer updateByordersState4 = orderShowMapper.updateByordersState4(ordersId);
        if(updateByordersState4 > 0){
            return Result.success(ordersId,"修改成功");
        }
        return Result.error(402,"修改失败");
    }


}


