package com.muyu.cloud.market.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.cloud.market.domin.Product;
import com.muyu.cloud.market.domin.req.ProductListReq;
import com.muyu.cloud.market.domin.resp.ChosehowpayResp;
import com.muyu.cloud.market.domin.resp.ProductListResp;
import com.muyu.cloud.market.domin.resp.ProductTotalListResp;
import com.muyu.cloud.market.mapper.ProductApiMapper;
import com.muyu.cloud.market.service.ProductApiService;
import com.muyu.common.core.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @Author：weiran
 * @Package：com.muyu.cloud.market.service.impl
 * @Project：cloud-market
 * @name：ProductApiServiceImpl
 * @Date：2024/8/20 15:02
 */
@Service
public class ProductApiServiceImpl extends ServiceImpl<ProductApiMapper, Product> implements ProductApiService {

    @Autowired
    private ProductApiMapper productApiMapper;

    /**
     * 查询全部商品接口
     * @param productListReq
     * @return
     */
    @Override
    public ProductTotalListResp selectList(ProductListReq productListReq) {
        Integer pageNum = productListReq.getPageNum();
        Integer pageSize = productListReq.getPageSize();
        LambdaQueryWrapper<Product> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(StringUtils.isNotEmpty(productListReq.getProductName()),
                Product::getProductName,productListReq.getProductName());
        queryWrapper.eq(Product::getProductState, 1);
        queryWrapper.eq(StringUtils.isNotEmpty(productListReq.getProductType()),
                Product::getProductType,productListReq.getProductType());
        long count = this.count(queryWrapper);
        queryWrapper.orderByDesc(Product::getProductSales);
        queryWrapper.last("LIMIT " + ((pageNum - 1) * pageSize) + ", " + pageSize);
        List<Product> productList = this.list(queryWrapper);
        List<ProductListResp> productListResps = productList.stream()
                .map(product -> ProductListResp.productListRespbuild(product))
                .toList();
        return ProductTotalListResp.of(productListResps, count);
    }




    /**
     * 查询热点产品
     *
     * 销量前五的产品
     * @return
     */
    @Override
    public List<ProductListResp> selecthostportList() {
        LambdaQueryWrapper<Product> queryWrapper = new LambdaQueryWrapper<>();
        //按销量降序排序
        queryWrapper.orderByDesc(Product::getProductSales);
        //限制返回的结果数量为5
        queryWrapper.last("limit "+5);
        List<Product> products = this.list(queryWrapper);
        List<ProductListResp> productListResps = products.stream()
                .map(product-> ProductListResp.productListRespbuild(product)) // 静态方法引用
                .collect(Collectors.toList());

        return productListResps;
    }

    /**
     * 产品类型查询
     *
     * @return
     */
    @Override
    public List<String> selectproductTypeList() {
        return productApiMapper.selectDistinctProductTypes();
    }


    /**
     * 产品的支付规格及对应的价格
     * @return
     */
    @Override
    public List<ChosehowpayResp> selectspecification(ChosehowpayResp chosehowpayResp) {
        return productApiMapper.selectspecification(chosehowpayResp);
    }



    /**
     * 判断接口是否已被购买
     * @param product
     * @return
     */
    @Override
    public String selectremark(Product product) {
        return productApiMapper.selectremark(product);
    }

    /**
     * 测试次数-1
     * @param product
     * @return
     */
    @Override
    public Integer reducetestcount(Product product) {
        Integer reducetestcount = productApiMapper.reducetestcount(product);
        return reducetestcount;
    }


    /*
    判断测试次数
     */
    @Override
    public Integer iftest(Product product) {
        Integer iftest = productApiMapper.iftest(product);
        return iftest;
    }


}
