package com.muyu.cloud.market.service.impl;

import cn.hutool.core.util.RandomUtil;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.cloud.market.domin.User;
import com.muyu.cloud.market.domin.req.LinkEmailReq;
import com.muyu.cloud.market.mapper.UserMapper;
import com.muyu.common.security.service.TokenService;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.common.system.domain.LoginUser;
import jakarta.mail.MessagingException;
import jakarta.mail.internet.MimeMessage;
import jakarta.servlet.http.HttpServletRequest;
import org.apache.commons.lang3.RandomUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.data.redis.core.TimeoutUtils;
import org.springframework.mail.MailException;
import org.springframework.mail.SimpleMailMessage;
import org.springframework.mail.javamail.JavaMailSender;
import org.springframework.mail.javamail.MimeMessageHelper;
import org.springframework.stereotype.Service;

import java.util.concurrent.TimeUnit;

/**
 * @Author：weiran
 * @Package：com.muyu.cloud.market.service.impl
 * @Project：cloud-market
 * @name：UserService
 * @Date：2024/8/27 19:32
 */
@Service
public class UserServiceImpl extends ServiceImpl<UserMapper, User> implements com.muyu.cloud.market.service.UserService {

    @Autowired
    private TokenService tokenService;
    @Autowired
    private UserMapper userMapper;
    @Autowired
    private JavaMailSender javaMailSender;
    @Autowired
    private StringRedisTemplate redisTemplate;



    /**
     * 邮箱绑定
     * @param linkEmailReq
     * @return
     */
    @Override
    public void linkemail(LinkEmailReq linkEmailReq, HttpServletRequest request) {
        String token = SecurityUtils.getToken();// 获取当前Token
        LoginUser loginUser = tokenService.getLoginUser(token); // 获取当前登录用户
        if (loginUser == null) {
            throw new RuntimeException("用户未登录或Token无效");
        }
        // 从请求对象中获取新的邮箱地址
        String newEmail = linkEmailReq.getEmail();
        // 如果新邮箱地址为空或无效，可以抛出异常或返回错误提示（这里简单处理为抛出异常）
        if (newEmail == null || newEmail.isEmpty()) {
            throw new RuntimeException("绑定邮箱地址不能为空");
        }

        //判断验证码是否对得上
        String code = redisTemplate.opsForValue().get(newEmail);
        if (!code.equals(linkEmailReq.getCode())){
            throw new RuntimeException("邮箱绑定失败,验证码错误");
        }

        User user = new User();
        user.setEmail(newEmail);
        int result = userMapper.update(null,
                new UpdateWrapper<User>().set("email", newEmail).eq("user_id", loginUser.getUserid()));
        if (result == 0) {
            throw new RuntimeException("邮箱绑定失败，可能用户不存在或已被其他操作修改");
        }

    }

    /**
     * 发送邮箱验证
     * @param email
     * @return
     */
    @Override
    public String sendcode(String email) {
        if (email.isEmpty()){
            throw new RuntimeException("邮箱不能为空");
        }
        //生成验证码
        String code = RandomUtil.randomNumbers(4);
        //验证码存入redis中
        redisTemplate.opsForValue().set(email, code,5, TimeUnit.MINUTES);

        MimeMessage mimeMessage = javaMailSender.createMimeMessage();
        try {
            MimeMessageHelper helper  = new MimeMessageHelper(mimeMessage,true);
            helper.setFrom("2392355487@qq.com");
            helper.setTo(email);
            helper.setSubject("验证码请查收");
            helper.setText(code);
            javaMailSender.send(mimeMessage);
        } catch (MessagingException e) {
            // 记录日志或进行其他恢复操作
            throw new RuntimeException("邮件发送失败：" + e.getMessage());
        }
        return code;

    }

    @Override
    public void updcompanyId(Long userid, Integer companyId) {
        userMapper.updcompanyId(userid,companyId);
    }
}
