package com.muyu.cloud.market.util.poi3;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.metadata.Head;
import com.alibaba.excel.support.ExcelTypeEnum;
import com.alibaba.excel.util.CollectionUtils;
import com.alibaba.excel.write.merge.AbstractMergeStrategy;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.alibaba.excel.write.metadata.style.WriteCellStyle;
import com.alibaba.excel.write.metadata.style.WriteFont;
import com.alibaba.excel.write.style.HorizontalCellStyleStrategy;
import com.muyu.cloud.market.domin.Orders;
import jakarta.servlet.http.HttpServletResponse;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.poi.ss.formula.functions.T;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.FillPatternType;
import org.apache.poi.ss.usermodel.IndexedColors;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.util.CellRangeAddress;
import org.springframework.stereotype.Component;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

// 自定义合并策略 该类继承了AbstractMergeStrategy抽象合并策略，需要重写merge()方法
@Component
@Data
@NoArgsConstructor
public  class EasyExcelUtil extends AbstractMergeStrategy {



    /**
     * 分组，每几行合并一次
     */
    private List<Integer> exportFieldGroupCountList;

    /**
     * 目标合并列index
     */
    private Integer targetColumnIndex;

    // 需要开始合并单元格的首行index
    private Integer rowIndex;

    // exportDataList为待合并目标列的值
    public EasyExcelUtil(List<String> exportDataList, Integer targetColumnIndex) {
        this.exportFieldGroupCountList = getGroupCountList(exportDataList);
        this.targetColumnIndex = targetColumnIndex;
    }


    @Override
    protected void merge(Sheet sheet, Cell cell, Head head, Integer relativeRowIndex) {

        if (null == rowIndex) {
            rowIndex = cell.getRowIndex();
        }
        // 仅从首行以及目标列的单元格开始合并，忽略其他
        if (cell.getRowIndex() == rowIndex && cell.getColumnIndex() == targetColumnIndex) {
            mergeGroupColumn(sheet);
        }
    }

    private void mergeGroupColumn(Sheet sheet) {
        int rowCount = rowIndex;
        for (Integer count : exportFieldGroupCountList) {
            if(count == 1) {
                rowCount += count;
                continue ;
            }
            // 合并单元格
            CellRangeAddress cellRangeAddress = new CellRangeAddress(rowCount, rowCount + count - 1, targetColumnIndex, targetColumnIndex);
            sheet.addMergedRegionUnsafe(cellRangeAddress);
            rowCount += count;
        }
    }

    // 该方法将目标列根据值是否相同连续可合并，存储可合并的行数
    private List<Integer> getGroupCountList(List<String> exportDataList){
        if (CollectionUtils.isEmpty(exportDataList)) {
            return new ArrayList<>();
        }

        List<Integer> groupCountList = new ArrayList<>();
        int count = 1;

        for (int i = 1; i < exportDataList.size(); i++) {
            if (exportDataList.get(i).equals(exportDataList.get(i - 1))) {
                count++;
            } else {
                groupCountList.add(count);
                count = 1;
            }
        }
        // 处理完最后一条后
        groupCountList.add(count);
        return groupCountList;
    }


    // 修改WriteSheet的代码如下
    /**
     * @param response HttpServletResponse对象，用于输出Excel文件。
     * @param fileName 导出的Excel文件名
     * @param list  待导出的数据列表。
     * @param mergeIndex  合并的列数，Excel列是从0开始的
     * @param firstTitle  第一行标题.
     * @param secondTile   第二行标题.
     */
    public void writeExcel(HttpServletResponse response, String fileName, List<Orders> list, Integer mergeIndex, String firstTitle, String [] secondTile) {
        // 这里注意 有同学反应使用swagger 会导致各种问题，请直接用浏览器或者用postman
        response.setContentType("application/vnd.ms-excel");
        response.setCharacterEncoding("utf-8");
        // 这里URLEncoder.encode可以防止中文乱码 当然和easyexcel没有关系
        try {
            String name = URLEncoder.encode(fileName, "UTF-8");

            response.setHeader("Content-disposition", "attachment;filename="
                    + name + ".xlsx");

            List<List<String>> heads = new ArrayList<>();
            for (int i = 0; i < secondTile.length; i++) {
                heads.add(Arrays.asList(firstTitle,secondTile[i]));
            }


//            EasyExcel.write(response.getOutputStream(), Orders.class)
//                    .useDefaultStyle(false)
//                    .sheet("模板").head(Orders.class)
//                    .head(heads)
//                    //合并单元格new EasyExcelUtil(sexlist, mergeIndex)
//                    // 参数1：合并单元格的属性集合，参数2：合并的下标
//                    .registerWriteHandler(new EasyExcelUtil(list.stream().map(Orders::getOrdersSpecification).collect(Collectors.toList()), mergeIndex))
//                    .registerWriteHandler(new EasyExcelUtil(list.stream().map(Orders -> String.valueOf(Emp.getEmpName())).collect(Collectors.toList()), mergeIndex))
//                    //设置样式使用
//                    .registerWriteHandler(new CustomCellStyle())
//                    .doWrite(list);
//



        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }

    }



}
